@@ -30,8 +30,6 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	GLU_ERROR
 	GLU_EXTENSIONS
 	GLU_EXTERIOR
-	GLU_EXT_nurbs_tessellator
-	GLU_EXT_object_space_tess
 	GLU_FALSE
 	GLU_FILL
 	GLU_FLAT
@@ -229,7 +227,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	gluTessEndPolygon
 	gluTessNormal
 	gluTessProperty
-	gluTessVertex
+	gluTessVertex_p
 	gluUnProject
 	gluUnProject4
 ) ] );
@@ -249,8 +247,6 @@ our @EXPORT = qw(
 	GLU_ERROR
 	GLU_EXTENSIONS
 	GLU_EXTERIOR
-	GLU_EXT_nurbs_tessellator
-	GLU_EXT_object_space_tess
 	GLU_FALSE
 	GLU_FILL
 	GLU_FLAT
@@ -394,7 +390,7 @@ our @EXPORT = qw(
 	GLU_V_STEP
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -461,8 +457,6 @@ None by default.
   GLU_ERROR
   GLU_EXTENSIONS
   GLU_EXTERIOR
-  GLU_EXT_nurbs_tessellator
-  GLU_EXT_object_space_tess
   GLU_FALSE
   GLU_FILL
   GLU_FLAT
